==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/photos/l10n/ru.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Общедоступная ссылка",
    "Photos" : "Фото",
    "On This Day" : "В этот день",
    "Your memories under your control" : "Ваши воспоминания под вашим контролем",
    "All media" : "Все медиафайлы",
    "Videos" : "Видео",
    "Albums" : "Альбомы",
    "Collaborative albums" : "Совместные альбомы",
    "People" : "Люди",
    "Folders" : "Папки",
    "Favorites" : "Избранное",
    "On this day" : "В этот день",
    "Shared with you" : "Предоставленные вам",
    "Tags" : "Метки",
    "Places" : "Места",
    "Map" : "Карта",
    "Photos settings" : "Настройки фотографий",
    "Mark selection as favorite" : "Добавить выделенное в избранное",
    "Add selection to favorites" : "Добавить выделенное в избранное",
    "Remove selection from favorites" : "Удалить выбранные объекты из избранного",
    "Name of the album" : "Название",
    "Location of the album" : "Геопозиция",
    "Back" : "Назад",
    "Add collaborators" : "Добавить соавторов",
    "Save" : "Сохранить",
    "Create album" : "Создать альбом",
    "Add to Album" : "Добавить в альбом",
    "Add selection to album {albumName}" : "Добавить выделенное в альбом «{albumName}»",
    "Shared by" : "Доступ предоставлен",
    "Create a new album." : "Создать альбом",
    "Create new album" : "Создать альбом",
    "New album" : "Создать альбом",
    "_%n item_::_%n photos and videos_" : ["%n объект","%n фотографии и видео","%n фотографий и видео","%n фотографии и видео"],
    "Failed to fetch collaborators list." : "Не удалось получить список соавторов.",
    "Failed to update album." : "Не удалось изменить альбом.",
    "Add people or groups who can edit your album" : "Добавьте пользователей или группы, которые могут редактировать альбом",
    "Search people or groups" : "Введите имя пользователя или название группы…",
    "No recommendations. Start typing." : "Начните вводить имя...",
    "Group" : "Группа",
    "Remove {collaboratorLabel} from the collaborators list" : "Убрать {collaboratorLabel} из списка соавторов ",
    "Copy the public link" : "Скопировать общедоступную ссылку",
    "Public link copied!" : "Общедоступная ссылка скопирована",
    "Copy public link" : "Скопировать общедоступную ссылку",
    "Delete the public link" : "Удалить общедоступную ссылку",
    "Create public link share" : "Создать ссылку общего доступа",
    "Share via public link" : "Поделиться общедоступной ссылкой",
    "This collection does not exist" : "Эта коллекция не существует",
    "An error occurred" : "Произошла ошибка",
    "No picture for this day" : "Нет изображения на этот день",
    "Picture taken on this day will show up here." : "Фото, сделанное в этот день, будет показано здесь.",
    "More photos from this day" : "Больше фотографий с этого дня",
    "_%n photos_::_%n photos_" : ["%n фотография","%n фотографии","%n фотографий","%n фотографии"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n неназначенная фотография","%n неназначенные фотографии","%n неназначенных фотографий","%n неназначенных фотографий"],
    "Favorite" : "В избранное",
    "Favorite image, open the full size \"{name}\" image" : "Любимое изображение, открыть изображение \"{name}\" в полном размере",
    "Open the full size \"{name}\" image" : "Отрыть полноразмерное изображение «{name}»",
    "Select image {imageName}" : "Выбрать изображение «{imageName}»",
    "Open the \"{name}\" folder" : "Откройте папку \"{name}\"",
    "Back to {folder}" : "Вернуться в {folder}",
    "Go back" : "Назад",
    "Share this folder" : "Опубликовать эту папку",
    "Dates" : "Даты",
    "Jump to specific date in list" : "Перейти к конкретной дате в списке",
    "Jump to {date}" : "Перейти к {date}",
    "Add to {destination}" : "Добавить в {destination}",
    "There are no photos or videos yet!" : "Пока не содержит ни одной фотографии или видео.",
    "_{years} year ago_::_{years} years ago_" : ["{years} год назад","{years} лет назад","{years} лет назад","{years} лет назад"],
    "Enable squared photos view" : "Включить квадратный просмотр фотографий",
    "Delete source directory" : "Удалить исходный каталог",
    "Select a source folder for your media" : "Выберите исходную папку для ваших медиафайлов",
    "All folders" : "Все папки",
    "Add a Photos source for the timelines" : "Добавьте источник фотографий для временных шкал",
    "Add folder" : "Добавить папку",
    "Select the default upload location for your media" : "Выберите место загрузки по умолчанию для ваших медиафайлов",
    "Home" : "Главная страница",
    "Choose default Photos upload and Albums location" : "Выберите местоположение загрузки фотографий и альбомов по умолчанию",
    "Choose a different folder" : "Выбрать другую папку",
    "View" : "Просмотр",
    "Media folders" : "Медиа папки",
    "Choose the folders from where photos and videos are shown." : "Выберите папки, из которых будут отображаться фотографии и видео.",
    "Upload folder" : "Папка для загрузки",
    "Choose the folder where photos and albums are uploaded to." : "Выберите папку, в которую загружаются фотографии и альбомы.",
    "_%n photo_::_%n photos_" : ["%n фотография","%n фотографии","%n фотографий","%n фотографии"],
    "Unselect all" : "Отменить выделение для всех",
    "Add photos to this album" : "Добавить фотографии в альбом",
    "Manage collaborators for this album" : "Управление списком соавторов альбома",
    "Open actions menu" : "Открыть меню действий",
    "Edit album details" : "Изменить альбом",
    "Download all files in album" : "Скачать все файлы альбома",
    "Delete album" : "Удалить альбом",
    "Download selected files" : "Скачать выбранные файлы",
    "Remove selection from album" : "Удалить выбранное из альбома",
    "This album does not have any photos or videos yet!" : "Альбом пока не содержит ни одной фотографии или видео.",
    "Add photos to {albumName}" : "Добавить фотографии в {albumName}",
    "Manage collaborators" : "Управление списком соавторов",
    "Save collaborators for this album." : "Сохранить список соавторов альбома.",
    "Cover photo for album {albumName}" : "Заглавное изображение альбома «{albumName}»",
    "There is no album yet!" : "Пока нет ни одного альбома",
    "This person could not be found" : "Эта метка лица не найдена",
    "Rename person" : "Переименовать",
    "Merge with different person" : "Объединить с другой меткой",
    "Download selected photos" : "Скачать выбранные фотографии",
    "Remove from favorites" : "Убрать из избранного",
    "Remove person" : "Удалить",
    "Name of this person" : "Имя",
    "Save." : "Сохранить",
    "Merge person" : "Объединить метки",
    "Move to different person" : "Назначить другую метку лица",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица"],
    "_Remove photo from person_::_Remove photos from person_" : ["Снять отметку лица с фотографии","Снять отметку лица с фотографий","Снять отметку лица с фотографий","Снять отметку лица с фотографий"],
    "This might take some time depending on the size of your photo library." : "Выполнение этого действия может занять некоторое время, зависящее от размера библиотеки фотографий.",
    "Recognized people will show up here" : "Тут будут показаны лица людей, которые удалось распознать",
    "This folder does not exist" : "Эта папка не существует",
    "Loading folders …" : "Выполняется загрузка папок…",
    "No photos in here" : "Здесь нет ни одной фотографии",
    "Taken on {date} at {time}" : "Снят {date} в {time}",
    "This place does not have any photos or videos yet!" : "С этим местом пока не связано ни одной фотографии или видео.",
    "Add photos to this place" : "Связать фотографии с этим местом",
    "Cover photo for place {placeName}" : "Заглавное изображение для места «{placeName}»",
    "There is no place yet!" : "Пока нет ни одного места.",
    "Back to tags overview" : "Вернуться к просмотру меток",
    "No photos with this tag yet" : "Нет ни одной фотографии с этой меткой",
    "No tags yet" : "Нет ни одной метки",
    "Photos with tags will show up here" : "Здесь будут показаны фотографии, которым присвоены метки",
    "Popular tags" : "Популярные метки",
    "All tags" : "Все теги",
    "Add to album" : "Добавить в альбом",
    "Delete selection" : "Удалить выбранное",
    "No photos or videos in here" : "Нет ни одной фотографии или видео",
    "Unassigned faces" : "Неназначенные лица",
    "Failed to fetch collection." : "Не удалось получить коллекцию.",
    "Failed to fetch collections list." : "Не удалось получить список коллекций.",
    "Failed to fetch faces list." : "Не удалось получить список лиц.",
    "All your media" : "Все фотографии и видео",
    "Album {title}" : "Альбом «{title}»",
    "Shared Albums" : "Опубликованные альбомы",
    "Shared album {title}" : "Опубликованный альбом «{title}»",
    "Public album {title}" : "Общедоступный альбом «{title}»",
    "Tagged photos" : "Фотографии с метками",
    "Tagged photo {title}" : "Фотография с метками «{title}»",
    "{title}'s face" : "Лицо {title}",
    "{startDate} to {endDate}" : "С {startDate} по {endDate}",
    "Details" : "Свойства",
    "Could not load photos folder" : "Не удалось загрузить папку с фотографиями",
    "One of the source folders does not exists" : "Одна из исходных папок не существует",
    "Add" : "Добавить"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> php83-nextcloud-30.0.15.tgz: share/nextcloud/apps/photos/l10n/ru.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Общедоступная ссылка",
    "Photos" : "Фото",
    "On This Day" : "В этот день",
    "Your memories under your control" : "Ваши воспоминания под вашим контролем",
    "All media" : "Все медиафайлы",
    "Videos" : "Видео",
    "Albums" : "Альбомы",
    "Collaborative albums" : "Совместные альбомы",
    "People" : "Люди",
    "Folders" : "Папки",
    "Favorites" : "Избранное",
    "On this day" : "В этот день",
    "Shared with you" : "Предоставленные вам",
    "Tags" : "Метки",
    "Places" : "Места",
    "Map" : "Карта",
    "Photos settings" : "Настройки фотографий",
    "Mark selection as favorite" : "Добавить выделенное в избранное",
    "Add selection to favorites" : "Добавить выделенное в избранное",
    "Remove selection from favorites" : "Удалить выбранные объекты из избранного",
    "Name of the album" : "Название",
    "Location of the album" : "Геопозиция",
    "Back" : "Назад",
    "Add collaborators" : "Добавить соавторов",
    "Save" : "Сохранить",
    "Create album" : "Создать альбом",
    "Add to Album" : "Добавить в альбом",
    "Add selection to album {albumName}" : "Добавить выделенное в альбом «{albumName}»",
    "Shared by" : "Доступ предоставлен",
    "Create a new album." : "Создать альбом",
    "Create new album" : "Создать альбом",
    "New album" : "Создать альбом",
    "_%n item_::_%n photos and videos_" : ["%n объект","%n фотографии и видео","%n фотографий и видео","%n фотографии и видео"],
    "Failed to fetch collaborators list." : "Не удалось получить список соавторов.",
    "Failed to update album." : "Не удалось изменить альбом.",
    "Add people or groups who can edit your album" : "Добавьте пользователей или группы, которые могут редактировать альбом",
    "Search people or groups" : "Введите имя пользователя или название группы…",
    "No recommendations. Start typing." : "Начните вводить имя...",
    "Copy the public link" : "Скопировать общедоступную ссылку",
    "Public link copied!" : "Общедоступная ссылка скопирована",
    "Copy public link" : "Скопировать общедоступную ссылку",
    "Delete the public link" : "Удалить общедоступную ссылку",
    "Create public link share" : "Создать ссылку общего доступа",
    "Share via public link" : "Поделиться общедоступной ссылкой",
    "This collection does not exist" : "Эта коллекция не существует",
    "An error occurred" : "Произошла ошибка",
    "No picture for this day" : "Нет изображения на этот день",
    "Picture taken on this day will show up here." : "Фото, сделанное в этот день, будет показано здесь.",
    "More photos from this day" : "Больше фотографий с этого дня",
    "_%n photos_::_%n photos_" : ["%n фотография","%n фотографии","%n фотографий","%n фотографии"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n неназначенная фотография","%n неназначенные фотографии","%n неназначенных фотографий","%n неназначенных фотографий"],
    "Favorite" : "В избранное",
    "Favorite image, open the full size \"{name}\" image" : "Любимое изображение, открыть изображение \"{name}\" в полном размере",
    "Open the full size \"{name}\" image" : "Отрыть полноразмерное изображение «{name}»",
    "Select image {imageName}" : "Выбрать изображение «{imageName}»",
    "Open the \"{name}\" folder" : "Откройте папку \"{name}\"",
    "Go back" : "Назад",
    "Select a custom date range" : "Выберите произвольный диапазон дат",
    "Select a date range" : "Выберите диапазон дат",
    "Date range" : "Диапазон дат",
    "Select filters" : "Выберите фильтры",
    "Dates" : "Даты",
    "Jump to specific date in list" : "Перейти к конкретной дате в списке",
    "Jump to {date}" : "Перейти к {date}",
    "Add to {destination}" : "Добавить в {destination}",
    "The destination folder is owned by {owner}" : "Целевая папка принадлежит пользователю {owner}",
    "There are no photos or videos yet!" : "Пока не содержит ни одной фотографии или видео.",
    "_{years} year ago_::_{years} years ago_" : ["{years} год назад","{years} лет назад","{years} лет назад","{years} лет назад"],
    "Enable squared photos view" : "Включить квадратный просмотр фотографий",
    "Delete source directory" : "Удалить исходный каталог",
    "Pick folder" : "Выберите папку",
    "Select a source folder for your media" : "Выберите исходную папку для ваших медиафайлов",
    "All folders" : "Все папки",
    "Add a Photos source for the timelines" : "Добавьте источник фотографий для временных шкал",
    "Add folder" : "Добавить папку",
    "Select the default upload location for your media" : "Выберите место загрузки по умолчанию для ваших медиафайлов",
    "Home" : "Главная страница",
    "Choose default Photos upload and Albums location" : "Выберите местоположение загрузки фотографий и альбомов по умолчанию",
    "Choose a different folder" : "Выбрать другую папку",
    "View" : "Просмотр",
    "Media folders" : "Медиа папки",
    "Choose the folders from where photos and videos are shown." : "Выберите папки, из которых будут отображаться фотографии и видео.",
    "Upload folder" : "Папка для загрузки",
    "Choose the folder where photos and albums are uploaded to." : "Выберите папку, в которую загружаются фотографии и альбомы.",
    "_%n photo_::_%n photos_" : ["%n фотография","%n фотографии","%n фотографий","%n фотографии"],
    "Unselect all" : "Отменить выделение для всех",
    "Add photos to this album" : "Добавить фотографии в альбом",
    "Manage collaborators for this album" : "Управление списком соавторов альбома",
    "Open actions menu" : "Открыть меню действий",
    "Edit album details" : "Изменить альбом",
    "Download all files in album" : "Скачать все файлы альбома",
    "Delete album" : "Удалить альбом",
    "Download selected files" : "Скачать выбранные файлы",
    "Remove selection from album" : "Удалить выбранное из альбома",
    "This album does not have any photos or videos yet!" : "Альбом пока не содержит ни одной фотографии или видео.",
    "Add photos to {albumName}" : "Добавить фотографии в {albumName}",
    "Manage collaborators" : "Управление списком соавторов",
    "Save collaborators for this album." : "Сохранить список соавторов альбома.",
    "Cover photo for album {albumName}" : "Заглавное изображение альбома «{albumName}»",
    "There is no album yet!" : "Пока нет ни одного альбома",
    "This person could not be found" : "Эта метка лица не найдена",
    "Rename person" : "Переименовать",
    "Merge with different person" : "Объединить с другой меткой",
    "Download selected photos" : "Скачать выбранные фотографии",
    "Remove from favorites" : "Убрать из избранного",
    "Remove person" : "Удалить",
    "Name of this person" : "Имя",
    "Save." : "Сохранить",
    "Merge person" : "Объединить метки",
    "Move to different person" : "Назначить другую метку лица",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица"],
    "_Remove photo from person_::_Remove photos from person_" : ["Снять отметку лица с фотографии","Снять отметку лица с фотографий","Снять отметку лица с фотографий","Снять отметку лица с фотографий"],
    "This might take some time depending on the size of your photo library." : "Выполнение этого действия может занять некоторое время, зависящее от размера библиотеки фотографий.",
    "Recognized people will show up here" : "Тут будут показаны лица людей, которые удалось распознать",
    "This folder does not exist" : "Эта папка не существует",
    "Loading folders…" : "Получение списка папок…",
    "No photos in here" : "Здесь нет ни одной фотографии",
    "Taken on {date} at {time}" : "Снят {date} в {time}",
    "This place does not have any photos or videos yet!" : "С этим местом пока не связано ни одной фотографии или видео.",
    "Add photos to this place" : "Связать фотографии с этим местом",
    "Cover photo for place {placeName}" : "Заглавное изображение для места «{placeName}»",
    "There is no place yet!" : "Пока нет ни одного места.",
    "Cover photo for shared album {albumName}" : "Обложка для общего альбома {albumName}",
    "Back to tags overview" : "Вернуться к просмотру меток",
    "No photos with this tag yet" : "Нет ни одной фотографии с этой меткой",
    "No tags yet" : "Нет ни одной метки",
    "Photos with tags will show up here" : "Здесь будут показаны фотографии, которым присвоены метки",
    "Popular tags" : "Популярные метки",
    "All tags" : "Все теги",
    "Create new album from filters" : "Создать новый альбом на основе фильтров",
    "One of the source folders does not exist" : "Одна из исходных папок не существует",
    "Add to album" : "Добавить в альбом",
    "Delete selection" : "Удалить выбранное",
    "No photos or videos in here" : "Нет ни одной фотографии или видео",
    "Unassigned faces" : "Неназначенные лица",
    "Failed to fetch collection." : "Не удалось получить коллекцию.",
    "Failed to fetch collections list." : "Не удалось получить список коллекций.",
    "Failed to fetch faces list." : "Не удалось получить список лиц.",
    "Error fetching files" : "Ошибка при получении файлов",
    "All your media" : "Все фотографии и видео",
    "Album {title}" : "Альбом «{title}»",
    "Shared Albums" : "Опубликованные альбомы",
    "Shared album {title}" : "Опубликованный альбом «{title}»",
    "Public album {title}" : "Общедоступный альбом «{title}»",
    "Tagged photos" : "Фотографии с метками",
    "Tagged photo {title}" : "Фотография с метками «{title}»",
    "{title}'s face" : "Лицо {title}",
    "Last week" : "Прошлая неделя",
    "Last Month" : "В прошлом месяце",
    "Custom…" : "Настроить...",
    "{startDate} to {endDate}" : "С {startDate} по {endDate}",
    "Details" : "Свойства",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Не удалось добавить {fileBaseName} в коллекцию {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Не удалось удалить {fileBaseName}",
    "Failed to create {collectionFileName}" : "Не удалось создать {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Не удалось переименовать {currentCollectionFileName} в {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Не удалось обновить свойства {collectionFileName} следующими параметрами: {properties}",
    "Failed to delete {collectionFileName}" : "Не удалось удалить {collectionFileName}",
    "Failed to move {fileBaseName} to person {faceName}" : "Не удалось переместить {fileBaseName} к {faceName}",
    "Failed to remove {fileBaseName}" : "Не удалось удалить {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Не удалось переименовать {oldName} в {faceName}",
    "Failed to delete {faceName}" : "Не удалось удалить {faceName}",
    "Failed to delete {fileId}" : "Не удалось удалить {fileId}",
    "Failed to delete {fileName}" : "Не удалось удалить {fileName}",
    "Failed to set favorite state for {fileId}" : "Не удалось добавить {fileId} в избранное",
    "Failed to set favorite state for {fileName}" : "Не удалось добавить {fileName} в избранное",
    "Could not load photos folder" : "Не удалось загрузить папку с фотографиями",
    "Group" : "Группа",
    "Remove {collaboratorLabel} from the collaborators list" : "Убрать {collaboratorLabel} из списка соавторов ",
    "Back to {folder}" : "Вернуться в {folder}",
    "Share this folder" : "Опубликовать эту папку",
    "Loading folders …" : "Выполняется загрузка папок…",
    "One of the source folders does not exists" : "Одна из исходных папок не существует",
    "Add" : "Добавить"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
